pub type Decoder<'a, K, I> = Take<UnboundedDecoder<'a, K, I>>;Expand description
A bounded decoder, decoding symbols from a source of bits.
Aliased Type
pub struct Decoder<'a, K, I> { /* private fields */ }pub type Decoder<'a, K, I> = Take<UnboundedDecoder<'a, K, I>>;A bounded decoder, decoding symbols from a source of bits.
pub struct Decoder<'a, K, I> { /* private fields */ }